Type: Package
Title: Tidy C++ Header-Only Definitions for Parts of the C API of R
Version: 0.0.10
Date: 2026-03-15
Description: Core parts of the C API of R are wrapped in a C++ namespace via a set of inline functions giving a tidier representation of the underlying data structures and functionality using a header-only implementation without additional dependencies.
Suggests: Rcpp, RcppSpdlog, simplermarkdown
VignetteBuilder: simplermarkdown
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
URL: https://github.com/eddelbuettel/tidycpp, https://dirk.eddelbuettel.com/code/tidycpp.html
BugReports: https://github.com/eddelbuettel/tidycpp/issues
NeedsCompilation: no
Packaged: 2026-03-15 14:17:40 UTC; edd
Author: Dirk Eddelbuettel ORCID iD [aut, cre]
Maintainer: Dirk Eddelbuettel <edd@debian.org>
Repository: CRAN
Date/Publication: 2026-03-15 14:40:02 UTC

Tidy C++ Header-Only Definitions for Parts of the C API of R

Description

Core parts of the C API of R are wrapped in a C++ namespace via a set of inline functions giving a tidier representation of the underlying data structures and functionality using a header-only implementation without additional dependencies.

Package Content

Index of help topics:

tidyCpp-package                                             Tidy C++ Header-Only Definitions for Parts of the C API of R

Maintainer

Dirk Eddelbuettel <edd@debian.org>

Author(s)

Dirk Eddelbuettel [aut, cre] (ORCID: <https://orcid.org/0000-0001-6419-907X>)

Examples

## Not run: 
    ## see the source files in the snippets/ directory of the package
    ## check for (optional, only in Suggests:) Rcpp, and also wrapped in a
    ## dontrun as it takes 10s at CRAN (yet only 3.5 here) yielding a NOTE
    if (requireNamespace("Rcpp", quietly=TRUE)) {
        Rcpp::sourceCpp(system.file("snippets", "convolveExample.cpp", package="tidyCpp"))
    }

## End(Not run)